pub struct EchoProvider;Trait Implementations
Sourceimpl ChatProvider for EchoProvider
impl ChatProvider for EchoProvider
Sourcefn chat_with_tools<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
messages: &'life1 [ChatMessage],
_tools: Option<&'life2 [Tool]>,
_json_schema: Option<StructuredOutputFormat>,
) -> Pin<Box<dyn Future<Output = Result<Box<dyn ChatResponse>, LLMError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn chat_with_tools<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
messages: &'life1 [ChatMessage],
_tools: Option<&'life2 [Tool]>,
_json_schema: Option<StructuredOutputFormat>,
) -> Pin<Box<dyn Future<Output = Result<Box<dyn ChatResponse>, LLMError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Sends a chat request to the provider with a sequence of messages and tools. Read more
Sourcefn chat<'life0, 'life1, 'async_trait>(
&'life0 self,
messages: &'life1 [ChatMessage],
json_schema: Option<StructuredOutputFormat>,
) -> Pin<Box<dyn Future<Output = Result<Box<dyn ChatResponse>, LLMError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn chat<'life0, 'life1, 'async_trait>(
&'life0 self,
messages: &'life1 [ChatMessage],
json_schema: Option<StructuredOutputFormat>,
) -> Pin<Box<dyn Future<Output = Result<Box<dyn ChatResponse>, LLMError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Sends a chat request to the provider with a sequence of messages. Read more
Sourcefn chat_with_web_search<'life0, 'async_trait>(
&'life0 self,
_input: String,
) -> Pin<Box<dyn Future<Output = Result<Box<dyn ChatResponse>, LLMError>> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
fn chat_with_web_search<'life0, 'async_trait>(
&'life0 self,
_input: String,
) -> Pin<Box<dyn Future<Output = Result<Box<dyn ChatResponse>, LLMError>> + Send + 'async_trait>>where
'life0: 'async_trait,
Self: 'async_trait,
Sends a chat with web search request to the provider Read more
Sourcefn chat_stream<'life0, 'life1, 'async_trait>(
&'life0 self,
_messages: &'life1 [ChatMessage],
_json_schema: Option<StructuredOutputFormat>,
) -> Pin<Box<dyn Future<Output = Result<Pin<Box<dyn Stream<Item = Result<String, LLMError>> + Send>>, LLMError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
fn chat_stream<'life0, 'life1, 'async_trait>(
&'life0 self,
_messages: &'life1 [ChatMessage],
_json_schema: Option<StructuredOutputFormat>,
) -> Pin<Box<dyn Future<Output = Result<Pin<Box<dyn Stream<Item = Result<String, LLMError>> + Send>>, LLMError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: 'async_trait,
Sends a streaming chat request to the provider with a sequence of messages. Read more
Sourcefn chat_stream_struct<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
_messages: &'life1 [ChatMessage],
_tools: Option<&'life2 [Tool]>,
_json_schema: Option<StructuredOutputFormat>,
) -> Pin<Box<dyn Future<Output = Result<Pin<Box<dyn Stream<Item = Result<StreamResponse, LLMError>> + Send>>, LLMError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Self: 'async_trait,
fn chat_stream_struct<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
_messages: &'life1 [ChatMessage],
_tools: Option<&'life2 [Tool]>,
_json_schema: Option<StructuredOutputFormat>,
) -> Pin<Box<dyn Future<Output = Result<Pin<Box<dyn Stream<Item = Result<StreamResponse, LLMError>> + Send>>, LLMError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Self: 'async_trait,
Sends a streaming chat request that returns structured response chunks. Read more
Sourcefn chat_stream_with_tools<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
_messages: &'life1 [ChatMessage],
_tools: Option<&'life2 [Tool]>,
_json_schema: Option<StructuredOutputFormat>,
) -> Pin<Box<dyn Future<Output = Result<Pin<Box<dyn Stream<Item = Result<StreamChunk, LLMError>> + Send>>, LLMError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Self: 'async_trait,
fn chat_stream_with_tools<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
_messages: &'life1 [ChatMessage],
_tools: Option<&'life2 [Tool]>,
_json_schema: Option<StructuredOutputFormat>,
) -> Pin<Box<dyn Future<Output = Result<Pin<Box<dyn Stream<Item = Result<StreamChunk, LLMError>> + Send>>, LLMError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Self: 'async_trait,
Sends a streaming chat request with tool support. Read more
Sourceimpl CompletionProvider for EchoProvider
impl CompletionProvider for EchoProvider
Sourcefn complete<'life0, 'life1, 'async_trait>(
&'life0 self,
request: &'life1 CompletionRequest,
_json_schema: Option<StructuredOutputFormat>,
) -> Pin<Box<dyn Future<Output = Result<CompletionResponse, LLMError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn complete<'life0, 'life1, 'async_trait>(
&'life0 self,
request: &'life1 CompletionRequest,
_json_schema: Option<StructuredOutputFormat>,
) -> Pin<Box<dyn Future<Output = Result<CompletionResponse, LLMError>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Sends a completion request to generate text. Read more
Sourceimpl Debug for EchoProvider
impl Debug for EchoProvider
Sourceimpl Default for EchoProvider
impl Default for EchoProvider
Sourcefn default() -> EchoProvider
fn default() -> EchoProvider
Returns the “default value” for a type. Read more
Sourceimpl EmbeddingProvider for EchoProvider
impl EmbeddingProvider for EchoProvider
Sourceimpl HasConfig for EchoProvider
impl HasConfig for EchoProvider
Sourceimpl ModelsProvider for EchoProvider
impl ModelsProvider for EchoProvider
Sourcefn list_models<'life0, 'life1, 'async_trait>(
&'life0 self,
_request: Option<&'life1 ModelListRequest>,
) -> Pin<Box<dyn Future<Output = Result<Box<dyn ModelListResponse>, LLMError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: Sync + 'async_trait,
fn list_models<'life0, 'life1, 'async_trait>(
&'life0 self,
_request: Option<&'life1 ModelListRequest>,
) -> Pin<Box<dyn Future<Output = Result<Box<dyn ModelListResponse>, LLMError>> + Send + 'async_trait>>where
'life0: 'async_trait,
'life1: 'async_trait,
Self: Sync + 'async_trait,
Asynchronously retrieves the list of available models ID’s from the provider. Read more
impl LLMProvider for EchoProvider